@@ -55,7 +55,7 @@
 
 #if defined(LIBC_SCCS) && !defined(lint)
 static char sccsid[] = "@(#)res_send.c	8.1 (Berkeley) 6/4/93";
-static char rcsid[] = "res_send.c,v 1.3 1995/10/15 15:10:35 hjl Exp";
+static char rcsid[] = "$Id: res_send.c,v 1.6 1996/06/05 16:07:39 hjl Exp $";
 #endif /* LIBC_SCCS and not lint */
 
 	/* change this to "0"
@@ -93,6 +93,9 @@ static int s = -1;	/* socket used for communications */
 static int connected = 0;	/* is the socket connected */
 static int vc = 0;	/* is the socket a virtual ciruit? */
 
+extern int writev( int, const struct iovec *, size_t);
+extern void putshort(u_short l, u_char *msgp);
+
 #ifndef FD_SET
 /* XXX - should be in portability.h */
 #define	NFDBITS		32
@@ -121,13 +124,10 @@ static int vc = 0;	/* is the socket a virtual ciruit? */
 			fprintf args;\
 			__fp_nquery(query, size, stdout);\
 		} else {}
-    static void
-    Aerror(file, string, error, address)
-	FILE *file;
-	char *string;
-	int error;
-	struct sockaddr_in address;
-    {
+
+static void
+Aerror( FILE *file, char *string, int error, struct sockaddr_in address )
+{
 	int save = errno;
 
 	if (_res.options & RES_DEBUG) {
@@ -138,13 +138,11 @@ static int vc = 0;	/* is the socket a virtual ciruit? */
 			strerror(error));
 	}
 	errno = save;
-    }
-    static void
-    Perror(file, string, error)
-	FILE *file;
-	char *string;
-	int error;
-    {
+}
+
+static void
+Perror( FILE *file, char *string, int error )
+{
 	int save = errno;
 
 	if (_res.options & RES_DEBUG) {
@@ -152,23 +150,31 @@ static int vc = 0;	/* is the socket a virtual ciruit? */
 			string, strerror(error));
 	}
 	errno = save;
-    }
-#endif
+}
+#endif	/* ndef DEBUG */
 
 static res_send_qhook Qhook = NULL;
 static res_send_rhook Rhook = NULL;
 
+void _res_close( void );
+int res_send( const u_char *, int, u_char *, int );
+int res_queriesmatch( const u_char *, const u_char *,
+					  const u_char *, const u_char * );
+int res_nameinquery( const char *, register int, register int,
+					 const u_char *, const u_char * );
+int res_isourserver( const struct sockaddr_in * );
+void res_send_setrhook( res_send_rhook );
+void res_send_setqhook( res_send_qhook );
+
 void
-res_send_setqhook(hook)
-	res_send_qhook hook;
+res_send_setqhook( res_send_qhook hook )
 {
 
 	Qhook = hook;
 }
 
 void
-res_send_setrhook(hook)
-	res_send_rhook hook;
+res_send_setrhook( res_send_rhook hook )
 {
 
 	Rhook = hook;
@@ -188,8 +194,7 @@ res_send_setrhook(hook)
  *	paul vixie, 29may94
  */
 int
-res_isourserver(inp)
-	const struct sockaddr_in *inp;
+res_isourserver( const struct sockaddr_in *inp )
 {
 	struct sockaddr_in ina;
 	register int ns, ret;
@@ -225,10 +230,8 @@ res_isourserver(inp)
  *	paul vixie, 29may94
  */
 int
-res_nameinquery(name, type, class, buf, eom)
-	const char *name;
-	register int type, class;
-	const u_char *buf, *eom;
+res_nameinquery( const char *name, register int type, register int class,
+					 const u_char *buf, const u_char *eom )
 {
 	register const u_char *cp = buf + HFIXEDSZ;
 	int qdcount = ntohs(((HEADER*)buf)->qdcount);
@@ -267,9 +270,8 @@ res_nameinquery(name, type, class, buf, eom)
  *	paul vixie, 29may94
  */
 int
-res_queriesmatch(buf1, eom1, buf2, eom2)
-	const u_char *buf1, *eom1;
-	const u_char *buf2, *eom2;
+res_queriesmatch( const u_char *buf1, const u_char *eom1,
+					  const u_char *buf2, const u_char *eom2 )
 {
 	register const u_char *cp = buf1 + HFIXEDSZ;
 	int qdcount = ntohs(((HEADER*)buf1)->qdcount);
@@ -293,11 +295,7 @@ res_queriesmatch(buf1, eom1, buf2, eom2)
 }
 
 int
-res_send(buf, buflen, ans, anssiz)
-	const u_char *buf;
-	int buflen;
-	u_char *ans;
-	int anssiz;
+res_send( const u_char *buf, int buflen, u_char *ans, int anssiz )
 {
 	HEADER *hp = (HEADER *) buf;
 	HEADER *anhp = (HEADER *) ans;
@@ -765,7 +763,7 @@ res_send(buf, buflen, ans, anssiz)
  * This routine is not expected to be user visible.
  */
 void
-_res_close()
+_res_close( void )
 {
 	if (s >= 0) {
 		(void) close(s);
