@@ -4,9 +4,13 @@
 
 extern void * ___brk_addr;
 
+extern int __init_brk (void);
+
 void *
 __sbrk(ptrdiff_t increment)
 {
+    if (__init_brk () == 0)
+    {
 	register void * tmp asm ("%d1") = ___brk_addr+increment;
 	__asm__ volatile ("movel %1,%/d0\n\t"
 			  "trap  #0\n\t"
@@ -16,7 +20,8 @@ __sbrk(ptrdiff_t increment)
 	if (___brk_addr == tmp)
 		return tmp-increment;
 	errno = ENOMEM;
-	return ((void *) -1);
+    }
+    return ((void *) -1);
 }
 
 #include <gnu-stabs.h>
